@@ -19,6 +19,9 @@ class Registry:
 
     def register(self, name, klass):
         """Register an email class for preview"""
+        if not issubclass(klass, Email):
+            raise ValueError("Wrapped class must subclass Email")
+
         if name in self._registry:
             raise AlreadyRegistered()
 
@@ -34,8 +37,6 @@ _default_registry = Registry() #pylint: disable=invalid-name
 def register(name):
     """Register the given object the wrapped handler class"""
     def wrapper(email_class):
-        if not issubclass(email_class, Email):
-            raise ValueError("Wrapped class must subclass Email")
         _default_registry.register(name, email_class)
 
         return email_class
